==> kubernetes-model-certificates-5.8.0-sources.jar: io/fabric8/kubernetes/api/model/certificates/v1beta1/CertificateSigningRequestBuilder.java <==
package io.fabric8.kubernetes.api.model.certificates.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CertificateSigningRequestBuilder extends io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluentImpl<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequest,io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestBuilder>{
  public CertificateSigningRequestBuilder() {
    this(false);
  }
  public CertificateSigningRequestBuilder(java.lang.Boolean validationEnabled) {
    this(new CertificateSigningRequest(), validationEnabled);
  }
  public CertificateSigningRequestBuilder(io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent<?> fluent) {
    this(fluent, false);
  }
  public CertificateSigningRequestBuilder(io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CertificateSigningRequest(), validationEnabled);
  }
  public CertificateSigningRequestBuilder(io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent<?> fluent,io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequest instance) {
    this(fluent, instance, false);
  }
  public CertificateSigningRequestBuilder(io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent<?> fluent,io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequest instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  public CertificateSigningRequestBuilder(io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequest instance) {
    this(instance,false);
  }
  public CertificateSigningRequestBuilder(io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequest instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequest build() {
    CertificateSigningRequest buildable = new CertificateSigningRequest(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CertificateSigningRequestBuilder that = (CertificateSigningRequestBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> kubernetes-model-certificates-5.12.2-sources.jar: io/fabric8/kubernetes/api/model/certificates/v1beta1/CertificateSigningRequestBuilder.java <==
package io.fabric8.kubernetes.api.model.certificates.v1beta1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class CertificateSigningRequestBuilder extends io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluentImpl<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequest,io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestBuilder>{
  public CertificateSigningRequestBuilder() {
    this(false);
  }
  public CertificateSigningRequestBuilder(java.lang.Boolean validationEnabled) {
    this(new CertificateSigningRequest(), validationEnabled);
  }
  public CertificateSigningRequestBuilder(io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent<?> fluent) {
    this(fluent, false);
  }
  public CertificateSigningRequestBuilder(io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new CertificateSigningRequest(), validationEnabled);
  }
  public CertificateSigningRequestBuilder(io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent<?> fluent,io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequest instance) {
    this(fluent, instance, false);
  }
  public CertificateSigningRequestBuilder(io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent<?> fluent,io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequest instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withApiVersion(instance.getApiVersion()); 
    fluent.withKind(instance.getKind()); 
    fluent.withMetadata(instance.getMetadata()); 
    fluent.withSpec(instance.getSpec()); 
    fluent.withStatus(instance.getStatus()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public CertificateSigningRequestBuilder(io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequest instance) {
    this(instance,false);
  }
  public CertificateSigningRequestBuilder(io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequest instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequestFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.kubernetes.api.model.certificates.v1beta1.CertificateSigningRequest build() {
    CertificateSigningRequest buildable = new CertificateSigningRequest(fluent.getApiVersion(),fluent.getKind(),fluent.getMetadata(),fluent.getSpec(),fluent.getStatus());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    CertificateSigningRequestBuilder that = (CertificateSigningRequestBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}
